export function isDefined(value) {
    if (typeof value === 'object') {
        return !!value && Object.keys(value).length !== 0;
    }
    return !(value === undefined || value === null || value === '' || value === 0 || value === '0');
}
export function flat(data, prefix = '') {
    if (!isDefined(data)) {
        return undefined;
    }
    let result = {};
    for (const key in data) {
        if (typeof data[key] == 'object' && data[key] !== null && !Array.isArray(data[key])) {
            const flatten = flat(data[key], prefix + '.' + key);
            result = { ...result, ...flatten };
        }
        else {
            const stringifiedValue = stringify(data[key]);
            const identifier = (prefix + '.' + key).replace(/^\.(\w+\.)?/, '');
            result[identifier] = stringifiedValue;
        }
    }
    return result;
}
export const flattenProperties = (arrayPropertyValue) => {
    let arrayProperties = {};
    for (const [key, value] of Object.entries(arrayPropertyValue)) {
        if (typeof value == 'object' && value !== null) {
            arrayProperties = { ...arrayProperties, ...flat({ [key]: value }) };
        }
        else {
            arrayProperties = Object.assign(arrayProperties, { [key]: value });
        }
    }
    return arrayProperties;
};
function stringify(value) {
    if (typeof value === 'string') {
        return value;
    }
    if (typeof value === 'number' || typeof value === 'boolean') {
        return value.toString();
    }
    return JSON.stringify(value);
}
//# sourceMappingURL=utils.js.map